#Copyright STACKEO - INRIA 2020
#!/usr/bin/python
import os
MODULE_DIR = os.path.realpath(os.path.join(__file__, '..'))
STACKML_URL_SCHEMA = 'https://stkml.stackeo.io/_static/stackml.schema.json'
STKML_PACKAGES = '.stkml_packages'
STKML_EXTENSION = 'stkml.yaml'
__version__ = '1.0.2a'
